FlutterTabBarLite class

Inheritance

Constructors

FlutterTabBarLite.horizontal({Key? key, bool scrollable = false, List<String>? titles, List<IconData>? prefixIcons, List<IconData>? suffixIcons, Color? backgroundColor = Colors.blue, Color selectedTextColor = Colors.black87, Color unselectedItemTextColor = Colors.white, Color selectedItemBgColor = Colors.white, Color unselectedItemBgColor = Colors.transparent, double selectedFontSize = 16, double unselectedFontSize = 14, dynamic onTabChange(int index)?, Duration animationDuration = const Duration(milliseconds: 300), LinearGradient? gradient, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 4), EdgeInsets itemPadding = const EdgeInsets.symmetric(horizontal: 8, vertical: 2), EdgeInsets itemMargin = const EdgeInsets.symmetric(horizontal: 3, vertical: 5), double iconSize = 20.0, double? spaceBetweenIconAndText = 4.0, bool animateItemSize = true, double borderRadius = 8, double itemBorderRadius = 4})
factory
FlutterTabBarLite.vertical({Key? key, List<String>? titles, List<IconData>? prefixIcons, List<IconData>? suffixIcons, Color? backgroundColor = Colors.blue, Color selectedTextColor = Colors.black87, Color unselectedItemTextColor = Colors.white, Color selectedItemBgColor = Colors.white, Color unselectedItemBgColor = Colors.transparent, dynamic onTabChange(int index)?, Duration animationDuration = const Duration(milliseconds: 300), LinearGradient? gradient, EdgeInsets padding = const EdgeInsets.symmetric(horizontal: 4, vertical: 4), EdgeInsets itemPadding = const EdgeInsets.symmetric(horizontal: 8, vertical: 2), EdgeInsets itemMargin = const EdgeInsets.symmetric(horizontal: 3, vertical: 5), double iconSize = 20.0, double? spaceBetweenIconAndText = 4.0, WrapAlignment alignment = WrapAlignment.center, VerticalDirection verticalDirection = VerticalDirection.down, double selectedFontSize = 16, double unselectedFontSize = 14, bool animateItemSize = true, double borderRadius = 8, double itemBorderRadius = 4})
factory

Properties

alignment → WrapAlignment?
final
animateItemSize → bool
final
animationDuration → Duration
final
axis → Axis
final
backgroundColor → Color?
final
borderRadius → double
final
gradient → LinearGradient?
final
hashCode → int
The hash code for this object.
no setterinherited
iconSize → double
final
itemBorderRadius → double
final
itemMargin → EdgeInsets
final
itemPadding → EdgeInsets
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTabChange → dynamic Function(int index)?
final
padding → EdgeInsets
final
prefixIcons → List<IconData>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollable → bool
final
selectedFontSize → double
final
selectedItemBgColor → Color
final
selectedTextColor → Color
final
spaceBetweenIconAndText → double?
final
suffixIcons → List<IconData>?
final
titles → List<String>?
final
unselectedFontSize → double
final
unselectedItemBgColor → Color
final
unselectedItemTextColor → Color
final
verticalDirection → VerticalDirection?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FlutterTabBarLite>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited